==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/dms/kotlin/outputs/GetEndpointKinesisSetting.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.dms.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property includeControlDetails
 * @property includeNullAndEmpty
 * @property includePartitionValue
 * @property includeTableAlterOperations
 * @property includeTransactionDetails
 * @property messageFormat
 * @property partitionIncludeSchemaTable
 * @property serviceAccessRoleArn
 * @property streamArn
 */
public data class GetEndpointKinesisSetting(
    public val includeControlDetails: Boolean,
    public val includeNullAndEmpty: Boolean,
    public val includePartitionValue: Boolean,
    public val includeTableAlterOperations: Boolean,
    public val includeTransactionDetails: Boolean,
    public val messageFormat: String,
    public val partitionIncludeSchemaTable: Boolean,
    public val serviceAccessRoleArn: String,
    public val streamArn: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.dms.outputs.GetEndpointKinesisSetting):
            GetEndpointKinesisSetting = GetEndpointKinesisSetting(
            includeControlDetails = javaType.includeControlDetails(),
            includeNullAndEmpty = javaType.includeNullAndEmpty(),
            includePartitionValue = javaType.includePartitionValue(),
            includeTableAlterOperations = javaType.includeTableAlterOperations(),
            includeTransactionDetails = javaType.includeTransactionDetails(),
            messageFormat = javaType.messageFormat(),
            partitionIncludeSchemaTable = javaType.partitionIncludeSchemaTable(),
            serviceAccessRoleArn = javaType.serviceAccessRoleArn(),
            streamArn = javaType.streamArn(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/dms/kotlin/outputs/GetEndpointKinesisSetting.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.dms.kotlin.outputs

import kotlin.Boolean
import kotlin.String
import kotlin.Suppress

/**
 *
 * @property includeControlDetails
 * @property includeNullAndEmpty
 * @property includePartitionValue
 * @property includeTableAlterOperations
 * @property includeTransactionDetails
 * @property messageFormat
 * @property partitionIncludeSchemaTable
 * @property serviceAccessRoleArn
 * @property streamArn
 */
public data class GetEndpointKinesisSetting(
    public val includeControlDetails: Boolean,
    public val includeNullAndEmpty: Boolean,
    public val includePartitionValue: Boolean,
    public val includeTableAlterOperations: Boolean,
    public val includeTransactionDetails: Boolean,
    public val messageFormat: String,
    public val partitionIncludeSchemaTable: Boolean,
    public val serviceAccessRoleArn: String,
    public val streamArn: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.dms.outputs.GetEndpointKinesisSetting): GetEndpointKinesisSetting = GetEndpointKinesisSetting(
            includeControlDetails = javaType.includeControlDetails(),
            includeNullAndEmpty = javaType.includeNullAndEmpty(),
            includePartitionValue = javaType.includePartitionValue(),
            includeTableAlterOperations = javaType.includeTableAlterOperations(),
            includeTransactionDetails = javaType.includeTransactionDetails(),
            messageFormat = javaType.messageFormat(),
            partitionIncludeSchemaTable = javaType.partitionIncludeSchemaTable(),
            serviceAccessRoleArn = javaType.serviceAccessRoleArn(),
            streamArn = javaType.streamArn(),
        )
    }
}
